package it.openutils.web.spring;

import it.openutils.web.util.MessageUtils;

import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ClassUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.beans.propertyeditors.CustomNumberEditor;
import org.springframework.beans.propertyeditors.StringTrimmerEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.servlet.mvc.SimpleFormController;


/**
 * @author fgiust
 * @version $Revision$ ($Author$)
 */
public class BaseFormController extends SimpleFormController
{

    /**
     * Logger.
     */
    protected Log log = LogFactory.getLog(getClass());

    /**
     * {@inheritDoc}
     */
    @Override
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder)
    {
        // convert java.util.Date
        SimpleDateFormat dateFormat = new SimpleDateFormat("dd/MM/yyyy");
        dateFormat.setLenient(false);
        binder.registerCustomEditor(Date.class, null, new CustomDateEditor(dateFormat, true));

        // convert Integers and Longs
        binder.registerCustomEditor(Long.class, null, new CustomNumberEditor(Long.class, true));
        binder.registerCustomEditor(Double.class, null, new EasyDoubleCustomEditor(Double.class, true));
        binder.registerCustomEditor(Integer.class, null, new CustomNumberEditor(Integer.class, true));
        binder.registerCustomEditor(Short.class, null, new CustomNumberEditor(Short.class, true));

        // trim empty strings
        binder.registerCustomEditor(String.class, new StringTrimmerEditor(true));

    }

    // /**
    // * Convenience method for getting a i18n key's value. Calling getMessageSourceAccessor() is used because the
    // * RequestContext variable is not set in unit tests b/c there's no DispatchServlet Request.
    // * @param msgKey
    // * @return String
    // */
    // public String getText(String msgKey)
    // {
    // String currentLocale = ThreadLocaleHolder.getLocale();
    // if (currentLocale != null)
    // {
    // return getMessageSourceAccessor().getMessage(msgKey, new Locale(currentLocale));
    // }
    //
    // return getMessageSourceAccessor().getMessage(msgKey);
    // }

    /**
     * Convenient method for getting a i18n key's value with a single string argument.
     * @param msgKey
     * @param arg
     * @return String
     */
    public String getText(String msgKey, Object arg)
    {
        return getText(msgKey, new Object[]{arg});
    }

    // /**
    // * Convenience method for getting a i18n key's value with arguments.
    // * @param msgKey
    // * @param args
    // * @return String
    // */
    // public String getText(String msgKey, Object[] args)
    // {
    // String currentLocale = ThreadLocaleHolder.getLocale();
    // if (currentLocale != null)
    // {
    // return getMessageSourceAccessor().getMessage(msgKey, args, new Locale(currentLocale));
    // }
    //
    // return getMessageSourceAccessor().getMessage(msgKey, args);
    // }

    public void saveMessage(HttpServletRequest request, String message)
    {
        MessageUtils.saveMessage(request, message);
    }

    public void saveError(HttpServletRequest request, String message)
    {
        MessageUtils.saveError(request, message);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString()
    {
        return ClassUtils.getShortClassName(getClass());
    }

}